@@ -1,12 +1,13 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import division
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
 
 import numpy as np
 
 from .core import Kernel1D, Kernel2D, Kernel
 from .utils import KernelSizeError
 from ..modeling import models
-from ..modeling.core import Parametric1DModel, Parametric2DModel
+from ..modeling.core import Fittable1DModel, Fittable2DModel
 
 __all__ = sorted(['Gaussian1DKernel', 'Gaussian2DKernel', 'CustomKernel',
                   'Box1DKernel', 'Box2DKernel', 'Tophat2DKernel',
@@ -33,10 +34,10 @@ class Gaussian1DKernel(Kernel1D):
 
     Parameters
     ----------
-    width : number
-        Width of the filter kernel.
+    stddev : number
+        Standard deviation of the Gaussian kernel.
     x_size : odd int, optional
-        Size of the kernel array. Default = 8 * width.
+        Size of the kernel array. Default = 8 * stddev
     mode : str, optional
         One of the following discretization modes:
             * 'center' (default)
@@ -79,12 +80,12 @@ class Gaussian1DKernel(Kernel1D):
     _separable = True
     _is_bool = False
 
-    def __init__(self, width, **kwargs):
-        self._model = models.Gaussian1D(1. / (np.sqrt(2 * np.pi) * width),
-                                        0, width)
-        self._default_size = _round_up_to_odd_integer(8 * width)
+    def __init__(self, stddev, **kwargs):
+        self._model = models.Gaussian1D(1. / (np.sqrt(2 * np.pi) * stddev),
+                                        0, stddev)
+        self._default_size = _round_up_to_odd_integer(8 * stddev)
         super(Gaussian1DKernel, self).__init__(**kwargs)
-        self._truncation = np.abs(1. - 1 / self._normalization)
+        self._truncation = np.abs(1. - self._array.sum())
 
 
 class Gaussian2DKernel(Kernel2D):
@@ -96,12 +97,12 @@ class Gaussian2DKernel(Kernel2D):
 
     Parameters
     ----------
-    width : number
-        Width of the filter kernel.
+    stddev : number
+        Standard deviation of the Gaussian kernel.
     x_size : odd int, optional
-        Size in x direction of the kernel array. Default = 8 * width.
+        Size in x direction of the kernel array. Default = 8 * stddev.
     y_size : odd int, optional
-        Size in y direction of the kernel array. Default = 8 * width.
+        Size in y direction of the kernel array. Default = 8 * stddev.
     mode : str, optional
         One of the following discretization modes:
             * 'center' (default)
@@ -145,12 +146,12 @@ class Gaussian2DKernel(Kernel2D):
     _separable = True
     _is_bool = False
 
-    def __init__(self, width, **kwargs):
-        self._model = models.Gaussian2D(1. / (2 * np.pi * width ** 2), 0,
-                                        0, width, width)
-        self._default_size = _round_up_to_odd_integer(8 * width)
+    def __init__(self, stddev, **kwargs):
+        self._model = models.Gaussian2D(1. / (2 * np.pi * stddev ** 2), 0,
+                                        0, stddev, stddev)
+        self._default_size = _round_up_to_odd_integer(8 * stddev)
         super(Gaussian2DKernel, self).__init__(**kwargs)
-        self._truncation = np.abs(1. - 1 / self._normalization)
+        self._truncation = np.abs(1. - self._array.sum())
 
 
 class Box1DKernel(Kernel1D):
@@ -160,7 +161,7 @@ class Box1DKernel(Kernel1D):
     The Box filter or running mean is a smoothing filter. It is not isotropic
     and can produce artifacts, when applied repeatedly to the same data.
 
-    By default the Box kernel uses the `linear_interp` discretization mode,
+    By default the Box kernel uses the ``linear_interp`` discretization mode,
     which allows non-shifting, even-sized kernels.  This is achieved by
     weighting the edge pixels with 1/2. E.g a Box kernel with an effective
     smoothing of 4 pixel would have the following array: [0.5, 1, 1, 1, 0.5].
@@ -228,7 +229,7 @@ class Box2DKernel(Kernel2D):
     The Box filter or running mean is a smoothing filter. It is not isotropic
     and can produce artifact, when applied repeatedly to the same data.
 
-    By default the Box kernel uses the `linear_interp` discretization mode,
+    By default the Box kernel uses the ``linear_interp`` discretization mode,
     which allows non-shifting, even-sized kernels.  This is achieved by
     weighting the edge pixels with 1/2.
 
@@ -362,7 +363,7 @@ class Ring2DKernel(Kernel2D):
         Inner radius of the ring kernel.
     width : number
         Width of the ring kernel.
-    mode: str, optional
+    mode : str, optional
         One of the following discretization modes:
             * 'center' (default)
                 Discretize model by taking the value
@@ -415,7 +416,8 @@ class Trapezoid1DKernel(Kernel1D):
     Parameters
     ----------
     width : number
-        Width of the filter kernel.
+        Width of the filter kernel, defined as the width of the constant part,
+        before it begins to slope down.
     slope : number
         Slope of the filter kernel's tails
     mode : str, optional
@@ -471,8 +473,9 @@ class TrapezoidDisk2DKernel(Kernel2D):
 
     Parameters
     ----------
-    width : number
-        Width of the filter kernel.
+    radius : number
+        Width of the filter kernel, defined as the width of the constant part,
+        before it begins to slope down.
     slope : number
         Slope of the filter kernel's tails
     mode : str, optional
@@ -542,7 +545,8 @@ class MexicanHat1DKernel(Kernel1D):
     Parameters
     ----------
     width : number
-        Width of the filter kernel.
+        Width of the filter kernel, defined as the standard deviation
+        of the Gaussian function from which it is derived.
     x_size : odd int, optional
         Size in x direction of the kernel array. Default = 8 * width.
     mode : str, optional
@@ -611,7 +615,8 @@ class MexicanHat2DKernel(Kernel2D):
     Parameters
     ----------
     width : number
-        Width of the filter kernel.
+        Width of the filter kernel, defined as the standard deviation
+        of the Gaussian function from which it is derived.
     x_size : odd int, optional
         Size in x direction of the kernel array. Default = 8 * width.
     y_size : odd int, optional
@@ -736,7 +741,7 @@ class Model1DKernel(Kernel1D):
 
     Parameters
     ----------
-    model : `~astropy.modeling.Parametric1DModel`
+    model : `~astropy.modeling.Fittable1DModel`
         Kernel response function model
     x_size : odd int, optional
         Size in x direction of the kernel array. Default = 8 * width.
@@ -760,11 +765,11 @@ class Model1DKernel(Kernel1D):
     Raises
     ------
     TypeError
-        If model is not an instance of `~astropy.modeling.Parametric1DModel`
+        If model is not an instance of `~astropy.modeling.Fittable1DModel`
 
     See also
     --------
-    Model2DKernel : Create kernel from `~astropy.modeling.Parametric2DModel`
+    Model2DKernel : Create kernel from `~astropy.modeling.Fittable2DModel`
     CustomKernel : Create kernel from list or array
 
     Examples
@@ -779,16 +784,16 @@ class Model1DKernel(Kernel1D):
 
         >>> gauss_kernel = Model1DKernel(gauss, x_size=9)
 
-    This kernel can now be used like a usual astropy kernel.
+    This kernel can now be used like a usual Astropy kernel.
     """
     _separable = False
     _is_bool = False
 
     def __init__(self, model, **kwargs):
-        if isinstance(model, Parametric1DModel):
+        if isinstance(model, Fittable1DModel):
             self._model = model
         else:
-            raise TypeError("Must be Parametric1DModel")
+            raise TypeError("Must be Fittable1DModel")
         super(Model1DKernel, self).__init__(**kwargs)
 
 
@@ -800,7 +805,7 @@ class Model2DKernel(Kernel2D):
 
     Parameters
     ----------
-    model : `~astropy.modeling.Parametric2DModel`
+    model : `~astropy.modeling.Fittable2DModel`
         Kernel response function model
     x_size : odd int, optional
         Size in x direction of the kernel array. Default = 8 * width.
@@ -826,11 +831,11 @@ class Model2DKernel(Kernel2D):
     Raises
     ------
     TypeError
-        If model is not an instance of `~astropy.modeling.Parametric2DModel`
+        If model is not an instance of `~astropy.modeling.Fittable2DModel`
 
     See also
     --------
-    Model1DKernel : Create kernel from `~astropy.modeling.Parametric1DModel`
+    Model1DKernel : Create kernel from `~astropy.modeling.Fittable1DModel`
     CustomKernel : Create kernel from list or array
 
     Examples
@@ -853,10 +858,10 @@ class Model2DKernel(Kernel2D):
 
     def __init__(self, model, **kwargs):
         self._separable = False
-        if isinstance(model, Parametric2DModel):
+        if isinstance(model, Fittable2DModel):
             self._model = model
         else:
-            raise TypeError("Must be Parametric2DModel")
+            raise TypeError("Must be Fittable2DModel")
         super(Model2DKernel, self).__init__(**kwargs)
 
 
