@@ -8,17 +8,19 @@ import warnings
 
 import numpy as np
 
-from ...units.format.fits import UnitScaleError
+from .. import registry as io_registry
+from ... import units as u
+from ...extern import six
+from ...extern.six import string_types
+from ...table import Table
 from ...utils import OrderedDict
 from ...utils.exceptions import AstropyUserWarning
-from .. import registry as io_registry
-from ...table import Table
-from ... import log
-from ... import units as u
+from astropy.units.format.fits import UnitScaleError
 
 from . import HDUList, TableHDU, BinTableHDU, GroupsHDU
 from . import FITS_rec
 from .hdu.hdulist import fitsopen as fits_open
+from .util import first
 
 
 # FITS file signature as per RFC 4047
@@ -105,13 +107,12 @@ def read_table_fits(input, hdu=None):
                 tables[ihdu] = hdu_item
 
         if len(tables) > 1:
-
             if hdu is None:
                 warnings.warn("hdu= was not specified but multiple tables"
                               " are present, reading in first available"
-                              " table (hdu={0})".format(tables.keys()[0]),
+                              " table (hdu={0})".format(first(tables)),
                               AstropyUserWarning)
-                hdu = tables.keys()[0]
+                hdu = first(tables)
 
             # hdu might not be an integer, so we first need to convert it
             # to the correct HDU index
@@ -123,7 +124,7 @@ def read_table_fits(input, hdu=None):
                 raise ValueError("No table found in hdu={0}".format(hdu))
 
         elif len(tables) == 1:
-            table = tables[tables.keys()[0]]
+            table = tables[first(tables)]
         else:
             raise ValueError("No table found")
 
@@ -208,8 +209,15 @@ def write_table_fits(input, output, overwrite=False):
         Whether to overwrite any existing file without warning.
     """
 
+    # Tables with mixin columns are not supported
+    if input.has_mixin_columns:
+        mixin_names = [name for name, col in input.columns.items()
+                       if not isinstance(col, input.ColumnClass)]
+        raise ValueError('cannot write table with mixin column(s) {0} to FITS'
+                         .format(mixin_names))
+
     # Check if output file already exists
-    if isinstance(output, basestring) and os.path.exists(output):
+    if isinstance(output, string_types) and os.path.exists(output):
         if overwrite:
             os.remove(output)
         else:
@@ -217,9 +225,14 @@ def write_table_fits(input, output, overwrite=False):
 
     # Create a new HDU object
     if input.masked:
+        #float column's default mask value needs to be Nan
+        for column in six.itervalues(input.columns):
+            fill_value = column.get_fill_value()
+            if column.dtype.kind == 'f' and np.allclose(fill_value, 1e20):
+                column.set_fill_value(np.nan)
+
         fits_rec = FITS_rec.from_columns(np.array(input.filled()))
         table_hdu = BinTableHDU(fits_rec)
-
         for col in table_hdu.columns:
             # Binary FITS tables support TNULL *only* for integer data columns
             # TODO: Determine a schema for handling non-integer masked columns
@@ -241,38 +254,47 @@ def write_table_fits(input, output, overwrite=False):
 
     # Set units for output HDU
     for col in table_hdu.columns:
-        if input[col.name].unit is not None:
+        unit = input[col.name].unit
+        if unit is not None:
             try:
-                col.unit = input[col.name].unit.to_string(format='fits')
+                col.unit = unit.to_string(format='fits')
             except UnitScaleError:
-                scale = input[col.name].unit.scale
+                scale = unit.scale
                 raise UnitScaleError(
                     "The column '{0}' could not be stored in FITS format "
                     "because it has a scale '({1})' that "
                     "is not recognized by the FITS standard. Either scale "
                     "the data or change the units.".format(col.name, str(scale)))
+            except ValueError:
+                warnings.warn(
+                    "The unit '{0}' could not be saved to FITS format".format(
+                        unit.to_string()), AstropyUserWarning)
 
     for key, value in input.meta.items():
 
         if is_column_keyword(key.upper()) or key.upper() in REMOVE_KEYWORDS:
 
-            warnings.warn("Meta-data keyword {0} will be ignored since it "
-                          "conflicts with a FITS reserved keyword".format(key), AstropyUserWarning)
+            warnings.warn(
+                "Meta-data keyword {0} will be ignored since it conflicts "
+                "with a FITS reserved keyword".format(key), AstropyUserWarning)
 
         if isinstance(value, list):
             for item in value:
                 try:
                     table_hdu.header.append((key, item))
                 except ValueError:
-                    warnings.warn("Attribute `{0}` of type {1} cannot be written "
-                                  "to FITS files - skipping".format(key,
-                                                               type(value)), AstropyUserWarning)
+                    warnings.warn(
+                        "Attribute `{0}` of type {1} cannot be written to "
+                        "FITS files - skipping".format(key, type(value)),
+                        AstropyUserWarning)
         else:
             try:
                 table_hdu.header[key] = value
             except ValueError:
-                warnings.warn("Attribute `{0}` of type {1} cannot be written to "
-                              "FITS files - skipping".format(key, type(value)), AstropyUserWarning)
+                warnings.warn(
+                    "Attribute `{0}` of type {1} cannot be written to FITS "
+                    "files - skipping".format(key, type(value)),
+                    AstropyUserWarning)
 
     # Write out file
     table_hdu.writeto(output)
