@@ -11,24 +11,26 @@ import difflib
 import fnmatch
 import functools
 import glob
-import inspect
 import io
 import textwrap
+import os.path
 
 from collections import defaultdict
-from itertools import islice, izip
+from itertools import islice
 
 import numpy as np
 
 from ... import __version__
-from ...extern.six.moves import reduce
+from ...extern import six
+from ...extern.six import u, string_types
+from ...extern.six.moves import zip, xrange, reduce
 from ...utils import indent
+from ...utils.compat.funcsigs import signature
 from .card import Card, BLANK_CARD
 from .header import Header
 # HDUList is used in one of the doctests
-from .hdu.hdulist import fitsopen, HDUList  # pylint: disable=W0611
+from .hdu.hdulist import fitsopen  # pylint: disable=W0611
 from .hdu.table import _TableLikeHDU
-from .util import u
 
 
 __all__ = ['FITSDiff', 'HDUDiff', 'HeaderDiff', 'ImageDataDiff', 'RawDataDiff',
@@ -84,27 +86,32 @@ class _BaseDiff(object):
 
         return not self.identical
 
+    if six.PY3:
+        __bool__ = __nonzero__
+        del __nonzero__
+
     @classmethod
     def fromdiff(cls, other, a, b):
         """
-        Returns a new Diff object of a specfic subclass from an existing diff
+        Returns a new Diff object of a specific subclass from an existing diff
         object, passing on the values for any arguments they share in common
         (such as ignore_keywords).
 
         For example::
 
-            >>> hdul1, hdul2 = HDUList(), HDUList()
-            >>> headera, headerb = Header(), Header()
-            >>> fd = FITSDiff(hdul1, hdul2, ignore_keywords=['*'])
-            >>> hd = HeaderDiff.fromdiff(fd, headera, headerb)
+            >>> from astropy.io import fits
+            >>> hdul1, hdul2 = fits.HDUList(), fits.HDUList()
+            >>> headera, headerb = fits.Header(), fits.Header()
+            >>> fd = fits.FITSDiff(hdul1, hdul2, ignore_keywords=['*'])
+            >>> hd = fits.HeaderDiff.fromdiff(fd, headera, headerb)
             >>> list(hd.ignore_keywords)
             ['*']
         """
 
-        args, _, _, _ = inspect.getargspec(cls.__init__)
+        sig = signature(cls.__init__)
         # The first 3 arguments of any Diff initializer are self, a, and b.
         kwargs = {}
-        for arg in args[3:]:
+        for arg in list(sig.parameters.keys())[3:]:
             if hasattr(other, arg):
                 kwargs[arg] = getattr(other, arg)
 
@@ -124,7 +131,7 @@ class _BaseDiff(object):
         return not any(getattr(self, attr) for attr in self.__dict__
                        if attr.startswith('diff_'))
 
-    def report(self, fileobj=None, indent=0):
+    def report(self, fileobj=None, indent=0, clobber=False):
         """
         Generates a text report on the differences (if any) between two
         objects, and either returns it as a string or writes it to a file-like
@@ -132,28 +139,46 @@ class _BaseDiff(object):
 
         Parameters
         ----------
-        fileobj : file-like object or None, optional
+        fileobj : file-like object, string, or None (optional)
             If `None`, this method returns the report as a string. Otherwise it
             returns `None` and writes the report to the given file-like object
-            (which must have a ``.write()`` method at a minimum).
+            (which must have a ``.write()`` method at a minimum), or to a new
+            file at the path specified.
 
         indent : int
             The number of 4 space tabs to indent the report.
 
+        clobber : bool
+            Whether the report output should overwrite an existing file, when
+            fileobj is specified as a path.
+
         Returns
         -------
         report : str or None
         """
 
         return_string = False
-        if fileobj is None:
+        filepath = None
+
+        if isinstance(fileobj, string_types):
+            if os.path.exists(fileobj) and not clobber:
+                raise IOError("File {0} exists, aborting (pass in "
+                              "clobber=True to overwrite)".format(fileobj))
+            else:
+                filepath = fileobj
+                fileobj = open(filepath, 'w')
+        elif fileobj is None:
             fileobj = io.StringIO()
             return_string = True
 
         self._fileobj = fileobj
         self._indent = indent  # This is used internally by _writeln
 
-        self._report()
+        try:
+            self._report()
+        finally:
+            if filepath:
+                fileobj.close()
 
         if return_string:
             return fileobj.getvalue()
@@ -213,7 +238,7 @@ class FITSDiff(_BaseDiff):
             differences.  Though the count of differences is the same either
             way, this allows controlling the number of different values that
             are kept in memory or output.  If a negative value is given, then
-            numdifs is treated as unlimited (default: 10).
+            numdiffs is treated as unlimited (default: 10).
 
         tolerance : float, optional
             The relative difference to allow when comparing two float values
@@ -224,24 +249,28 @@ class FITSDiff(_BaseDiff):
             Ignore extra whitespace at the end of string values either in
             headers or data. Extra leading whitespace is not ignored
             (default: True).
+
+        ignore_blank_cards : bool, optional
+            Ignore all cards that are blank, i.e. they only contain
+            whitespace (default: True).
         """
 
-        if isinstance(a, basestring):
+        if isinstance(a, string_types):
             try:
                 a = fitsopen(a)
-            except Exception as e:
+            except Exception as exc:
                 raise IOError("error opening file a (%s): %s: %s" %
-                              (a, e.__class.__name__, e.args[0]))
+                              (a, exc.__class__.__name__, exc.args[0]))
             close_a = True
         else:
             close_a = False
 
-        if isinstance(b, basestring):
+        if isinstance(b, string_types):
             try:
                 b = fitsopen(b)
-            except Exception as e:
+            except Exception as exc:
                 raise IOError("error opening file b (%s): %s: %s" %
-                              (b, e.__class.__name__, e.args[0]))
+                              (b, exc.__class__.__name__, exc.args[0]))
             close_b = True
         else:
             close_b = False
@@ -483,14 +512,14 @@ class HeaderDiff(_BaseDiff):
 
     - ``diff_keyword_values``: If any of the common keyword between the two
       headers have different values, they appear in this dict.  It has a
-      structure similar to `diff_duplicate_keywords`, with the keyword as the
+      structure similar to ``diff_duplicate_keywords``, with the keyword as the
       key, and a 2-tuple of the different values as the value.  For example::
 
           {'NAXIS': (2, 3)}
 
       means that the NAXIS keyword has a value of 2 in header a, and a value of
       3 in header b.  This excludes any keywords matched by the
-      `ignore_keywords` list.
+      ``ignore_keywords`` list.
 
     - ``diff_keyword_comments``: Like ``diff_keyword_values``, but contains
       differences between keyword comments.
@@ -552,9 +581,9 @@ class HeaderDiff(_BaseDiff):
         # (excluding keywords in ignore_keywords or in ignore_comments)
         self.diff_keyword_comments = defaultdict(lambda: [])
 
-        if isinstance(a, basestring):
+        if isinstance(a, string_types):
             a = Header.fromstring(a)
-        if isinstance(b, basestring):
+        if isinstance(b, string_types):
             b = Header.fromstring(b)
 
         if not (isinstance(a, Header) and isinstance(b, Header)):
@@ -580,7 +609,7 @@ class HeaderDiff(_BaseDiff):
             comments = {}
             for card in cards:
                 value = card.value
-                if self.ignore_blanks and isinstance(value, basestring):
+                if self.ignore_blanks and isinstance(value, string_types):
                     value = value.rstrip()
                 values.setdefault(card.keyword, []).append(value)
                 comments.setdefault(card.keyword, []).append(card.comment)
@@ -796,7 +825,7 @@ class ImageDataDiff(_BaseDiff):
             numdiffs = self.numdiffs
 
         self.diff_pixels = [(idx, (self.a[idx], self.b[idx]))
-                            for idx in islice(izip(*diffs), 0, numdiffs)]
+                            for idx in islice(zip(*diffs), 0, numdiffs)]
         self.diff_ratio = float(self.diff_total) / float(len(self.a.flat))
 
     def _report(self):
@@ -919,7 +948,7 @@ class TableDataDiff(_BaseDiff):
       objects.
 
     - ``diff_column_attributes``: Lists columns that are in both tables but
-      have different secondard attributes, such as TUNIT or TDISP.  The format
+      have different secondary attributes, such as TUNIT or TDISP.  The format
       is a list of 2-tuples: The first a tuple of the column name and the
       attribute, the second a tuple of the different values.
 
@@ -1195,7 +1224,7 @@ def report_diff_values(fileobj, a, b, ind=0):
         diff_indices = np.where(a != b)
         num_diffs = reduce(lambda x, y: x * y,
                            (len(d) for d in diff_indices), 1)
-        for idx in islice(izip(*diff_indices), 3):
+        for idx in islice(zip(*diff_indices), 3):
             fileobj.write(indent(u('  at %r:\n') % list(idx), ind))
             report_diff_values(fileobj, a[idx], b[idx], ind=ind + 1)
 
