@@ -1,6 +1,7 @@
 # Licensed under a 3-clause BSD style license - see PYFITS.rst
 
 import ctypes
+import gc
 import math
 import re
 import time
@@ -12,14 +13,14 @@ from .base import DELAYED, ExtensionHDU
 from .image import _ImageBaseHDU, ImageHDU
 from .table import BinTableHDU
 from ..card import Card
-from ..column import Column, ColDefs, _FormatP, TDEF_RE
+from ..column import Column, ColDefs, TDEF_RE
 from ..column import KEYWORD_NAMES as TABLE_KEYWORD_NAMES
 from ..fitsrec import FITS_rec
 from ..header import Header
-from ..util import _is_pseudo_unsigned, _unsigned_zero, _is_int
+from ..util import (_is_pseudo_unsigned, _unsigned_zero, _is_int,
+                    _get_array_mmap)
 
 from ....extern.six import string_types, iteritems
-from ....extern.six.moves import xrange, filter
 from ....utils import lazyproperty, deprecated
 from ....utils.compat import ignored
 from ....utils.exceptions import (AstropyPendingDeprecationWarning,
@@ -460,7 +461,7 @@ class CompImageHDU(BinTableHDU):
                convention are described at the `FITS Support Office web site
                <http://fits.gsfc.nasa.gov/registry/tilecompression.html>`_.
                Basically, the compressed image tiles are stored in rows of a
-               variable length arrray column in a FITS binary table.  The
+               variable length array column in a FITS binary table.  The
                astropy.io.fits recognizes that this binary table extension
                contains an image and treats it as if it were an image
                extension.  Under this tile-compression format, FITS header
@@ -508,7 +509,7 @@ class CompImageHDU(BinTableHDU):
         range -2 to -100).
 
         Very high compression factors (of 100 or more) can be achieved by using
-        large ``hcomp_scale`` values, however, this can produce undesireable
+        large ``hcomp_scale`` values, however, this can produce undesirable
         'blocky' artifacts in the compressed image.  A variation of the
         HCOMPRESS algorithm (called HSCOMPRESS) can be used in this case to
         apply a small amount of smoothing of the image when it is uncompressed
@@ -526,9 +527,9 @@ class CompImageHDU(BinTableHDU):
         GZIP, RICE, or HCOMPRESS).  This technique produces much higher
         compression factors than simply using the GZIP utility to externally
         compress the whole FITS file, but it also means that the original
-        floating point value pixel values are not exactly perserved.  When done
+        floating point value pixel values are not exactly preserved.  When done
         properly, this integer scaling technique will only discard the
-        insignificant noise while still preserving all the real imformation in
+        insignificant noise while still preserving all the real information in
         the image.  The amount of precision that is retained in the pixel
         values is controlled by the ``quantize_level`` parameter.  Larger
         values will result in compressed images whose pixels more closely match
@@ -548,7 +549,7 @@ class CompImageHDU(BinTableHDU):
         between adjacent scaled integer pixel values will equal 2.0 by default.
         Note that the RMS noise is independently calculated for each tile of
         the image, so the resulting integer scaling factor may fluctuate
-        slightly for each tile.  In some cases, it may be desireable to specify
+        slightly for each tile.  In some cases, it may be desirable to specify
         the exact quantization level to be used, instead of specifying it
         relative to the calculated noise value.  This may be done by specifying
         the negative of desired quantization level for the value of
@@ -1427,7 +1428,10 @@ class CompImageHDU(BinTableHDU):
         # data) from the file, if there is any.
         compressed_data = super(BinTableHDU, self).data
         if isinstance(compressed_data, np.rec.recarray):
-            del self.data
+            # Make sure not to use 'del self.data' so we don't accidentally
+            # go through the self.data.fdel and close the mmap underlying
+            # the compressed_data array
+            del self.__dict__['data']
             return compressed_data
         else:
             # This will actually set self.compressed_data with the
@@ -1437,6 +1441,26 @@ class CompImageHDU(BinTableHDU):
 
         return self.compressed_data
 
+    @compressed_data.deleter
+    def compressed_data(self):
+        # Deleting the compressed_data attribute has to be handled
+        # with a little care to prevent a reference leak
+        # First delete the ._coldefs attributes under it to break a possible
+        # reference cycle
+        if 'compressed_data' in self.__dict__:
+            del self.__dict__['compressed_data']._coldefs
+
+            # Now go ahead and delete from self.__dict__; normally
+            # lazyproperty.__delete__ does this for us, but we can prempt it to
+            # do some additional cleanup
+            del self.__dict__['compressed_data']
+
+            # If this file was mmap'd, numpy.memmap will hold open a file
+            # handle until the underlying mmap object is garbage-collected;
+            # since this reference leak can sometimes hang around longer than
+            # welcome go ahead and force a garbage collection
+            gc.collect()
+
     @lazyproperty
     @deprecated('0.3', alternative='the ``compressed_data`` attribute',
                 pending=True)
@@ -1457,7 +1481,7 @@ class CompImageHDU(BinTableHDU):
         # The header attribute is the header for the image data.  It
         # is not actually stored in the object dictionary.  Instead,
         # the _image_header is stored.  If the _image_header attribute
-        # has already been defined we just return it.  If not, we nust
+        # has already been defined we just return it.  If not, we must
         # create it from the table header (the _header attribute).
         if hasattr(self, '_image_header'):
             return self._image_header
@@ -1642,6 +1666,10 @@ class CompImageHDU(BinTableHDU):
                 del self._header['THEAP']
             self._theap = tbsize
 
+            # First delete the original compressed data, if it exists
+            del self.compressed_data
+
+
             # Compress the data.
             # The current implementation of compress_hdu assumes the empty
             # compressed data table has already been initialized in
@@ -1664,7 +1692,6 @@ class CompImageHDU(BinTableHDU):
         self.compressed_data._coldefs = self.columns
         self.compressed_data._heapoffset = self._theap
         self.compressed_data._heapsize = heapsize
-        self.compressed_data.formats = self.columns.formats
 
     @deprecated('0.3', alternative='(refactor your code)')
     def updateCompressedData(self):
@@ -1764,7 +1791,7 @@ class CompImageHDU(BinTableHDU):
         self._bitpix = _ImageBaseHDU.ImgCode[self.data.dtype.name]
         self._bzero = self.header.get('BZERO', 0)
         self._bscale = self.header.get('BSCALE', 1)
-        # Update BITPIX for the image header specificially
+        # Update BITPIX for the image header specifically
         # TODO: Make this more clear by using self._image_header, but only once
         # this has been fixed so that the _image_header attribute is guaranteed
         # to be valid
@@ -1810,7 +1837,7 @@ class CompImageHDU(BinTableHDU):
 
             # Now we need to perform an ugly hack to set the compressed data as
             # the .data attribute on the HDU so that the call to _writedata
-            # handles it propertly
+            # handles it properly
             self.__dict__['data'] = self.compressed_data
 
         return super(CompImageHDU, self)._prewriteto(checksum=checksum,
@@ -1841,6 +1868,17 @@ class CompImageHDU(BinTableHDU):
             else:
                 del self.data
 
+    def _close(self, closed=True):
+        super(CompImageHDU, self)._close(closed=closed)
+
+        # Also make sure to close access to the compressed data mmaps
+        if (closed and self._data_loaded and
+                _get_array_mmap(self.compressed_data) is not None):
+            del self.compressed_data
+            # Close off the deprected compData attribute as well if it has been
+            # used
+            del self.compData
+
     # TODO: This was copied right out of _ImageBaseHDU; get rid of it once we
     # find a way to rewrite this class as either a subclass or wrapper for an
     # ImageHDU
@@ -1910,7 +1948,7 @@ class CompImageHDU(BinTableHDU):
             # indices of slices (starting from 0)
             first_tile = self.data[tuple(slice(d) for d in tile_dims)]
 
-            # The checksum agorithm used is literally just the sum of the bytes
+            # The checksum algorithm used is literally just the sum of the bytes
             # of the tile data (not its actual floating point values).  Integer
             # overflow is irrelevant.
             csum = first_tile.view(dtype='uint8').sum()
