@@ -225,7 +225,15 @@ int compress_type_from_string(char* zcmptype) {
         return PLIO_1;
     } else if (0 == strcmp(zcmptype, "HCOMPRESS_1")) {
         return HCOMPRESS_1;
-    } else {
+    }
+#ifdef CFITSIO_SUPPORTS_SUBTRACTIVE_DITHER_2
+    /* CFITSIO adds a compression type alias for RICE_1 compression
+       as a flag for using subtractive_dither_2 */
+    else if (0 == strcmp(zcmptype, "RICE_ONE")) {
+        return RICE_1;
+    }
+#endif
+    else {
         PyErr_Format(PyExc_ValueError, "Unrecognized compression type: %s",
                      zcmptype);
         return -1;
@@ -237,7 +245,7 @@ int compress_type_from_string(char* zcmptype) {
 // conversion function (eg. PyString_AsString) an argument to a macro or
 // something, but I'm not sure yet how easy it is to generalize the error
 // handling
-int get_header_string(PyObject* header, char* keyword, char** val, char* def) {
+int get_header_string(PyObject* header, char* keyword, char* val, char* def) {
     PyObject* keystr;
     PyObject* keyval;
 #ifdef IS_PY3K
@@ -253,10 +261,10 @@ int get_header_string(PyObject* header, char* keyword, char** val, char* def) {
         // FITS header values should always be ASCII, but Latin1 is on the
         // safe side
         tmp = PyUnicode_AsLatin1String(keyval);
-        *val = PyBytes_AsString(tmp);
+        strncpy(val, PyBytes_AsString(tmp), 72);
         Py_DECREF(tmp);
 #else
-        *val = PyString_AsString(keyval);
+        strncpy(val, PyString_AsString(keyval), 72);
 #endif
         retval = 0;
     }
@@ -395,23 +403,6 @@ int get_header_longlong(PyObject* header, char* keyword, long long* val,
 }
 
 
-void* compression_realloc(void* ptr, size_t size) {
-    // This realloc()-like function actually just mallocs the requested
-    // size and copies from the original memory address into the new one, and
-    // returns the newly malloc'd address.
-    // This is generally less efficient than an actual realloc(), but the
-    // problem with using realloc in this case is that when it succeeds it will
-    // free() the original memory, which may still be in use by the ndarray
-    // using that memory as its data buffer.  This seems like the least hacky
-    // way around that for now.
-    // I'm open to other ideas though.
-    void* tmp;
-    tmp = malloc(size);
-    memcpy(tmp, ptr, size);
-    return tmp;
-}
-
-
 void tcolumns_from_header(fitsfile* fileptr, PyObject* header,
                           tcolumn** columns) {
     // Creates the array of tcolumn structures from the table column keywords
@@ -423,8 +414,8 @@ void tcolumns_from_header(fitsfile* fileptr, PyObject* header,
     unsigned int idx;
 
     int tfields;
-    char* ttype;
-    char* tform;
+    char ttype[72];
+    char tform[72];
     int dtcode;
     long trepeat;
     long twidth;
@@ -433,7 +424,10 @@ void tcolumns_from_header(fitsfile* fileptr, PyObject* header,
 
     get_header_int(header, "TFIELDS", &tfields, 0);
 
-    *columns = column = PyMem_New(tcolumn, (size_t) tfields);
+    // This used to use PyMem_New, but don't do that; CFITSIO will later
+    // free() this object when the file is closed, so just use malloc here
+    // *columns = column = PyMem_New(tcolumn, (size_t) tfields);
+    *columns = column = calloc((size_t) tfields, sizeof(tcolumn));
     if (column == NULL) {
         return;
     }
@@ -450,12 +444,12 @@ void tcolumns_from_header(fitsfile* fileptr, PyObject* header,
         column->twidth = 0;
 
         snprintf(tkw, 9, "TTYPE%u", idx);
-        get_header_string(header, tkw, &ttype, "");
+        get_header_string(header, tkw, ttype, "");
         strncpy(column->ttype, ttype, 69);
         column->ttype[69] = '\0';
 
         snprintf(tkw, 9, "TFORM%u", idx);
-        get_header_string(header, tkw, &tform, "");
+        get_header_string(header, tkw, tform, "");
         strncpy(column->tform, tform, 9);
         column->tform[9] = '\0';
         fits_binary_tform(tform, &dtcode, &trepeat, &twidth, &status);
@@ -503,9 +497,9 @@ void configure_compression(fitsfile* fileptr, PyObject* header) {
     tcolumn* columns;
 
     char keyword[9];
-    char* zname;
+    char zname[72];
     int znaxis;
-    char* tmp;
+    char tmp[72];
     float version;
 
     unsigned int idx;
@@ -572,7 +566,7 @@ void configure_compression(fitsfile* fileptr, PyObject* header) {
     }
     Fptr->cn_bzero = Fptr->zzero;
 
-    get_header_string(header, "ZCMPTYPE", &tmp, DEFAULT_COMPRESSION_TYPE);
+    get_header_string(header, "ZCMPTYPE", tmp, DEFAULT_COMPRESSION_TYPE);
     strncpy(Fptr->zcmptype, tmp, 11);
     Fptr->zcmptype[strlen(tmp)] = '\0';
 
@@ -590,6 +584,7 @@ void configure_compression(fitsfile* fileptr, PyObject* header) {
         znaxis = MAX_COMPRESS_DIM;
     }
 
+    Fptr->tilerow = NULL;
     Fptr->maxtilelen = 1;
     for (idx = 1; idx <= znaxis; idx++) {
         snprintf(keyword, 9, "ZNAXIS%u", idx);
@@ -613,7 +608,7 @@ void configure_compression(fitsfile* fileptr, PyObject* header) {
         // Assumes there are no gaps in the ZNAMEn keywords; this same
         // assumption was made in the Python code.  This could be done slightly
         // more flexibly by using a wildcard slice of the header
-        if (0 != get_header_string(header, keyword, &zname, "")) {
+        if (0 != get_header_string(header, keyword, zname, "")) {
             break;
         }
         snprintf(keyword, 9, "ZVAL%u", idx);
@@ -647,7 +642,7 @@ void configure_compression(fitsfile* fileptr, PyObject* header) {
 
     /* The ZQUANTIZ keyword determines the quantization algorithm; NO_QUANTIZE
        implies lossless compression */
-    if (0 == get_header_string(header, "ZQUANTIZ", &tmp, "")) {
+    if (0 == get_header_string(header, "ZQUANTIZ", tmp, "")) {
         /* Ugh; the fact that cfitsio defines its version as a float makes
            preprocessor comparison impossible */
         fits_get_version(&version);
@@ -711,7 +706,7 @@ void init_output_buffer(PyObject* hdu, void** buf, size_t* bufsize) {
 
     PyObject* header = NULL;
     char keyword[9];
-    char* tmp;
+    char tmp[72];
     int znaxis;
     int idx;
     int compress_type;
@@ -738,7 +733,7 @@ void init_output_buffer(PyObject* hdu, void** buf, size_t* bufsize) {
         maxtilelen *= tilelen;
     }
 
-    get_header_string(header, "ZCMPTYPE", &tmp, DEFAULT_COMPRESSION_TYPE);
+    get_header_string(header, "ZCMPTYPE", tmp, DEFAULT_COMPRESSION_TYPE);
     compress_type = compress_type_from_string(tmp);
     if (compress_type == RICE_1) {
         get_header_int(header, "ZVAL1", &rice_blocksize, 0);
@@ -815,7 +810,7 @@ fail:
 
 
 void open_from_hdu(fitsfile** fileptr, void** buf, size_t* bufsize,
-                   PyObject* hdu, tcolumn** columns) {
+                   PyObject* hdu, tcolumn** columns, int mode) {
     PyObject* header = NULL;
     FITSfile* Fptr;
 
@@ -851,6 +846,7 @@ void open_from_hdu(fitsfile** fileptr, void** buf, size_t* bufsize,
     Fptr = (*fileptr)->Fptr;
 
     // Now we have some fun munging some of the elements in the fitsfile struct
+    Fptr->writemode = mode;
     Fptr->open_count = 1;
     Fptr->hdutype = BINARY_TBL;  /* This is a binary table HDU */
     Fptr->lasthdu = 1;
@@ -921,7 +917,7 @@ PyObject* compression_compress_hdu(PyObject* self, PyObject* args)
         return NULL;
     }
 
-    open_from_hdu(&fileptr, &outbuf, &outbufsize, hdu, &columns);
+    open_from_hdu(&fileptr, &outbuf, &outbufsize, hdu, &columns, READWRITE);
     if (PyErr_Occurred()) {
         goto fail;
     }
@@ -1018,7 +1014,7 @@ PyObject* compression_decompress_hdu(PyObject* self, PyObject* args)
     long arrsize;
     unsigned int idx;
 
-    fitsfile* fileptr;
+    fitsfile* fileptr = NULL;
     int anynul = 0;
     int status = 0;
 
@@ -1033,9 +1029,14 @@ PyObject* compression_decompress_hdu(PyObject* self, PyObject* args)
     get_hdu_data_base(hdu, &inbuf, &inbufsize);
     if (PyErr_Occurred()) {
         return NULL;
+    } else if (inbufsize == 0) {
+        // The compressed data buffer is empty (probably zero rows, for an
+        // empty "compressed" image.  Just return None in this case.
+        Py_INCREF(Py_None);
+        return Py_None;
     }
 
-    open_from_hdu(&fileptr, &inbuf, &inbufsize, hdu, &columns);
+    open_from_hdu(&fileptr, &inbuf, &inbufsize, hdu, &columns, READONLY);
     if (PyErr_Occurred()) {
         return NULL;
     }
@@ -1065,10 +1066,15 @@ PyObject* compression_decompress_hdu(PyObject* self, PyObject* args)
     }
 
 fail:
+    // CFITSIO will free this object in the ffchdu function by way of
+    // fits_close_file; we need to let CFITSIO handle this so that it also
+    // cleans up the compressed tile cache
+    /*
     if (columns != NULL) {
         PyMem_Free(columns);
         fileptr->Fptr->tableptr = NULL;
     }
+    */
 
     if (fileptr != NULL) {
         status = 1;// Disable header-related errors
