@@ -818,7 +818,7 @@ class TestFileFunctions(FitsTestCase):
         mmap.mmap = MockMmap
 
         # Force the mmap test to be rerun
-        _File._mmap_available = None
+        _File._File__mmap_available = None
 
         try:
             self.copy_file('test0.fits')
@@ -835,43 +835,57 @@ class TestFileFunctions(FitsTestCase):
                 assert h[1].data[0, 0] == 999
         finally:
             mmap.mmap = old_mmap
-            _File._mmap_available = None
+            _File._File__mmap_available = None
 
-    def test_mmap_unwriteable(self):
-        """Regression test for
-        https://github.com/astropy/astropy/issues/968
-
-        Temporarily patches mmap.mmap to exhibit platform-specific bad
-        behavior.
+    def test_mmap_closing(self):
+        """
+        Tests that the mmap reference is closed/removed when there aren't any
+        HDU data references left.
         """
 
-        class MockMmap(mmap.mmap):
-            def flush(self):
-                raise mmap.error('flush is broken on this platform')
+        if not _File._mmap_available:
+            pytest.xfail('not expected to work on platforms without mmap '
+                         'support')
 
-        old_mmap = mmap.mmap
-        mmap.mmap = MockMmap
+        with fits.open(self.data('test0.fits'), memmap=True) as hdul:
+            assert hdul._file._mmap is None
 
-        # Force the mmap test to be rerun
-        _File._mmap_available = None
+            hdul[1].data
+            assert hdul._file._mmap is not None
 
-        try:
-            # TODO: Use self.copy_file once it's merged into Astropy
-            shutil.copy(self.data('test0.fits'), self.temp('test0.fits'))
-            with catch_warnings() as w:
-                with fits.open(self.temp('test0.fits'), mode='update',
-                               memmap=True) as h:
-                    h[1].data[0, 0] = 999
+            del hdul[1].data
+            # Should be no more references to data in the file so close the
+            # mmap
+            assert hdul._file._mmap is None
 
-                assert len(w) == 1
-                assert 'mmap.flush is unavailable' in str(w[0].message)
+            hdul[1].data
+            hdul[2].data
+            del hdul[1].data
+            # hdul[2].data is still references so keep the mmap open
+            assert hdul._file._mmap is not None
+            del hdul[2].data
+            assert hdul._file._mmap is None
 
-            # Double check that writing without mmap still worked
-            with fits.open(self.temp('test0.fits')) as h:
-                assert h[1].data[0, 0] == 999
-        finally:
-            mmap.mmap = old_mmap
-            _File._mmap_available = None
+        assert hdul._file._mmap is None
+
+        with fits.open(self.data('test0.fits'), memmap=True) as hdul:
+            hdul[1].data
+
+        # When the only reference to the data is on the hdu object, and the
+        # hdulist it belongs to has been closed, the mmap should be closed as
+        # well
+        assert hdul._file._mmap is None
+
+        with fits.open(self.data('test0.fits'), memmap=True) as hdul:
+            data = hdul[1].data
+            # also make a copy
+            data_copy = data.copy()
+
+        # The HDUList is closed; in fact, get rid of it completely
+        del hdul
+
+        # The data array should still work though...
+        assert np.all(data == data_copy)
 
     def test_uncloseable_file(self):
         """
