@@ -151,10 +151,10 @@ class TestImageFunctions(FitsTestCase):
             r[0].header.rename_key('fname', 'filename')
 
             # get a subsection of data
-            assert (r[2].data[:3, :3] ==
-                    np.array([[349, 349, 348],
-                              [349, 349, 347],
-                              [347, 350, 349]], dtype=np.int16)).all()
+            assert np.array_equal(r[2].data[:3, :3],
+                                  np.array([[349, 349, 348],
+                                            [349, 349, 347],
+                                            [347, 350, 349]], dtype=np.int16))
 
             # We can create a new FITS file by opening a new file with "append"
             # mode.
@@ -240,11 +240,11 @@ class TestImageFunctions(FitsTestCase):
         # create an HDU with data only
         data = np.ones((3, 5), dtype=np.float32)
         hdu = fits.ImageHDU(data=data, name='SCI')
-        assert (hdu.data ==
-                np.array([[1.,  1.,  1.,  1.,  1.],
-                          [1.,  1.,  1.,  1.,  1.],
-                          [1.,  1.,  1.,  1.,  1.]],
-                         dtype=np.float32)).all()
+        assert np.array_equal(hdu.data,
+                              np.array([[1.,  1.,  1.,  1.,  1.],
+                                        [1.,  1.,  1.,  1.,  1.],
+                                        [1.,  1.,  1.,  1.,  1.]],
+                                       dtype=np.float32))
 
         # create an HDU with header and data
         # notice that the header has the right NAXIS's since it is constructed
@@ -284,56 +284,80 @@ class TestImageFunctions(FitsTestCase):
     def test_section(self):
         # section testing
         fs = fits.open(self.data('arange.fits'))
-        assert (fs[0].section[3, 2, 5] == np.array([357])).all()
-        assert (fs[0].section[3, 2, :] ==
-                np.array([352, 353, 354, 355, 356, 357, 358, 359, 360, 361,
-                          362])).all()
-        assert (fs[0].section[3, 2, 4:] ==
-                np.array([356, 357, 358, 359, 360, 361, 362])).all()
-        assert (fs[0].section[3, 2, :8] ==
-                np.array([352, 353, 354, 355, 356, 357, 358, 359])).all()
-        assert (fs[0].section[3, 2, -8:8] ==
-                np.array([355, 356, 357, 358, 359])).all()
-        assert (fs[0].section[3, 2:5, :] ==
-                np.array([[352, 353, 354, 355, 356, 357, 358, 359, 360, 361,
-                           362],
-                          [363, 364, 365, 366, 367, 368, 369, 370, 371, 372,
-                           373],
-                          [374, 375, 376, 377, 378, 379, 380, 381, 382, 383,
-                           384]])).all()
+        assert np.array_equal(fs[0].section[3, 2, 5], 357)
+        assert np.array_equal(
+            fs[0].section[3, 2, :],
+            np.array([352, 353, 354, 355, 356, 357, 358, 359, 360, 361, 362]))
+        assert np.array_equal(fs[0].section[3, 2, 4:],
+                              np.array([356, 357, 358, 359, 360, 361, 362]))
+        assert np.array_equal(fs[0].section[3, 2, :8],
+                              np.array([352, 353, 354, 355, 356, 357, 358, 359]))
+        assert np.array_equal(fs[0].section[3, 2, -8:8],
+                              np.array([355, 356, 357, 358, 359]))
+        assert np.array_equal(
+            fs[0].section[3, 2:5, :],
+            np.array([[352, 353, 354, 355, 356, 357, 358, 359, 360, 361, 362],
+                      [363, 364, 365, 366, 367, 368, 369, 370, 371, 372, 373],
+                      [374, 375, 376, 377, 378, 379, 380, 381, 382, 383, 384]]))
 
-        assert (fs[0].section[3, :, :][:3, :3] ==
-                np.array([[330, 331, 332],
-                          [341, 342, 343],
-                          [352, 353, 354]])).all()
+        assert np.array_equal(fs[0].section[3, :, :][:3, :3],
+                              np.array([[330, 331, 332],
+                                        [341, 342, 343],
+                                        [352, 353, 354]]))
 
         dat = fs[0].data
-        assert (fs[0].section[3, 2:5, :8] == dat[3, 2:5, :8]).all()
-        assert (fs[0].section[3, 2:5, 3] == dat[3, 2:5, 3]).all()
+        assert np.array_equal(fs[0].section[3, 2:5, :8], dat[3, 2:5, :8])
+        assert np.array_equal(fs[0].section[3, 2:5, 3], dat[3, 2:5, 3])
 
-        assert (fs[0].section[3:6, :, :][:3, :3, :3] ==
-                np.array([[[330, 331, 332],
-                           [341, 342, 343],
-                           [352, 353, 354]],
-                          [[440, 441, 442],
-                           [451, 452, 453],
-                           [462, 463, 464]],
-                          [[550, 551, 552],
-                           [561, 562, 563],
-                           [572, 573, 574]]])).all()
+        assert np.array_equal(fs[0].section[3:6, :, :][:3, :3, :3],
+                              np.array([[[330, 331, 332],
+                                         [341, 342, 343],
+                                         [352, 353, 354]],
+                                        [[440, 441, 442],
+                                         [451, 452, 453],
+                                         [462, 463, 464]],
+                                        [[550, 551, 552],
+                                         [561, 562, 563],
+                                         [572, 573, 574]]]))
 
-        assert (fs[0].section[:, :, :][:3, :2, :2] ==
-                np.array([[[0,   1],
-                           [11,  12]],
-                          [[110, 111],
-                           [121, 122]],
-                          [[220, 221],
-                           [231, 232]]])).all()
+        assert np.array_equal(fs[0].section[:, :, :][:3, :2, :2],
+                              np.array([[[0,   1],
+                                         [11,  12]],
+                                        [[110, 111],
+                                         [121, 122]],
+                                        [[220, 221],
+                                         [231, 232]]]))
 
-        assert (fs[0].section[:, 2, :] == dat[:, 2, :]).all()
-        assert (fs[0].section[:, 2:5, :] == dat[:, 2:5, :]).all()
-        assert (fs[0].section[3:6, 3, :] == dat[3:6, 3, :]).all()
-        assert (fs[0].section[3:6, 3:7, :] == dat[3:6, 3:7, :]).all()
+        assert np.array_equal(fs[0].section[:, 2, :], dat[:, 2, :])
+        assert np.array_equal(fs[0].section[:, 2:5, :], dat[:, 2:5, :])
+        assert np.array_equal(fs[0].section[3:6, 3, :], dat[3:6, 3, :])
+        assert np.array_equal(fs[0].section[3:6, 3:7, :], dat[3:6, 3:7, :])
+
+        assert np.array_equal(fs[0].section[:, ::2], dat[:, ::2])
+        assert np.array_equal(fs[0].section[:, [1, 2, 4], 3],
+                              dat[:, [1, 2, 4], 3])
+        assert np.array_equal(
+            fs[0].section[:, np.array([True, False, True]), :],
+            dat[:, np.array([True, False, True]), :])
+
+        assert np.array_equal(
+            fs[0].section[3:6, 3, :, ...], dat[3:6, 3, :, ...])
+        assert np.array_equal(fs[0].section[..., ::2], dat[..., ::2])
+        assert np.array_equal(fs[0].section[..., [1, 2, 4], 3],
+                              dat[..., [1, 2, 4], 3])
+
+    def test_section_data_single(self):
+        a = np.array([1])
+        hdu = fits.PrimaryHDU(a)
+        hdu.writeto(self.temp('test_new.fits'))
+
+        hdul = fits.open(self.temp('test_new.fits'))
+        sec = hdul[0].section
+        dat = hdul[0].data
+        assert np.array_equal(sec[0], dat[0])
+        assert np.array_equal(sec[...], dat[...])
+        assert np.array_equal(sec[..., 0], dat[..., 0])
+        assert np.array_equal(sec[0, ...], dat[0, ...])
 
     def test_section_data_square(self):
         a = np.arange(4).reshape((2, 2))
@@ -618,6 +642,88 @@ class TestImageFunctions(FitsTestCase):
         hdul = fits.open(self.temp('test_new.fits'))
         assert np.isnan(hdul[1].data[1]).all()
 
+    def test_invalid_blanks(self):
+        """
+        Test that invalid use of the BLANK keyword leads to an appropriate
+        warning, and that the BLANK keyword is ignored when returning the
+        HDU data.
+
+        Regression test for https://github.com/astropy/astropy/issues/3865
+        """
+
+        arr = np.arange(5, dtype=np.float64)
+        hdu = fits.PrimaryHDU(data=arr)
+        hdu.header['BLANK'] = 2
+
+        with catch_warnings() as w:
+            hdu.writeto(self.temp('test_new.fits'))
+            # Allow the HDU to be written, but there should be a warning
+            # when writing a header with BLANK when then data is not
+            # int
+            assert len(w) == 1
+            assert "Invalid 'BLANK' keyword in header" in str(w[0].message)
+
+        # Should also get a warning when opening the file, and the BLANK
+        # value should not be applied
+        with catch_warnings() as w:
+            with fits.open(self.temp('test_new.fits')) as h:
+                assert len(w) == 1
+                assert "Invalid 'BLANK' keyword in header" in str(w[0].message)
+                assert np.all(arr == h[0].data)
+
+    def test_scale_back_with_blanks(self):
+        """
+        Test that when auto-rescaling integer data with "blank" values (where
+        the blanks are replaced by NaN in the float data), that the "BLANK"
+        keyword is removed from the header.
+
+        Further, test that when using the ``scale_back=True`` option the blank
+        values are restored properly.
+
+        Regression test for https://github.com/astropy/astropy/issues/3865
+        """
+
+        # Make the sample file
+        arr = np.arange(5, dtype=np.int32)
+        hdu = fits.PrimaryHDU(data=arr)
+        hdu.scale('int16', bscale=1.23)
+
+        # Creating data that uses BLANK is currently kludgy--a speparate issue
+        # TODO: Rewrite this test when scaling with blank support is better
+        # supported
+
+        # Let's just add a value to the data that should be converted to NaN
+        # when it is read back in:
+        hdu.data[0] = 9999
+        hdu.header['BLANK'] = 9999
+        hdu.writeto(self.temp('test.fits'))
+
+        with fits.open(self.temp('test.fits')) as hdul:
+            data = hdul[0].data
+            assert np.isnan(data[0])
+            hdul.writeto(self.temp('test2.fits'))
+
+        # Now reopen the newly written file.  It should not have a 'BLANK'
+        # keyword
+        with catch_warnings() as w:
+            with fits.open(self.temp('test2.fits')) as hdul2:
+                assert len(w) == 0
+                assert 'BLANK' not in hdul2[0].header
+                data = hdul2[0].data
+                assert np.isnan(data[0])
+
+        # Finally, test that scale_back keeps the BLANKs correctly
+        with fits.open(self.temp('test.fits'), scale_back=True,
+                       mode='update') as hdul3:
+            data = hdul3[0].data
+            assert np.isnan(data[0])
+
+        with fits.open(self.temp('test.fits'),
+                       do_not_scale_image_data=True) as hdul4:
+            assert hdul4[0].header['BLANK'] == 9999
+            assert hdul4[0].header['BSCALE'] == 1.23
+            assert hdul4[0].data[0] == 9999
+
     def test_bzero_with_floats(self):
         """Test use of the BZERO keyword in an image HDU containing float
         data.
@@ -786,6 +892,47 @@ class TestImageFunctions(FitsTestCase):
             assert 'NAXIS1' not in h[1].header
             assert 'NAXIS2' not in h[1].header
 
+    def test_invalid_blank(self):
+        """
+        Regression test for https://github.com/astropy/astropy/issues/2711
+
+        If the BLANK keyword contains an invalid value it should be ignored for
+        any calculations (though a warning should be issued).
+        """
+
+        data = np.arange(100, dtype=np.float64)
+        hdu = fits.PrimaryHDU(data)
+        hdu.header['BLANK'] = 'nan'
+        hdu.writeto(self.temp('test.fits'))
+
+        with catch_warnings() as w:
+            with fits.open(self.temp('test.fits')) as hdul:
+                assert np.all(hdul[0].data == data)
+
+        assert len(w) == 2
+        msg = "Invalid value for 'BLANK' keyword in header"
+        assert msg in str(w[0].message)
+        msg = "Invalid 'BLANK' keyword"
+        assert msg in str(w[1].message)
+
+    def test_scaled_image_fromfile(self):
+        """
+        Regression test for https://github.com/astropy/astropy/issues/2710
+        """
+
+        # Make some sample data
+        a = np.arange(100, dtype=np.float32)
+
+        hdu = fits.PrimaryHDU(data=a.copy())
+        hdu.scale(bscale=1.1)
+        hdu.writeto(self.temp('test.fits'))
+
+        with open(self.temp('test.fits'), 'rb') as f:
+            file_data = f.read()
+
+        hdul = fits.HDUList.fromstring(file_data)
+        assert np.allclose(hdul[0].data, a)
+
 
 class TestCompressedImage(FitsTestCase):
     def test_empty(self):
@@ -794,7 +941,7 @@ class TestCompressedImage(FitsTestCase):
         """
 
         hdu = fits.CompImageHDU()
-        hdu.data is None
+        assert hdu.data is None
         hdu.writeto(self.temp('test.fits'))
 
         with fits.open(self.temp('test.fits'), mode='update') as hdul:
@@ -1323,3 +1470,27 @@ class TestCompressedImage(FitsTestCase):
             assert np.all(comp_hdu.data[0] == arr[0])
             # The second tile uses lossy compression and may be somewhat off,
             # so we don't bother comparing it exactly
+
+    def test_duplicate_compression_header_keywords(self):
+        """
+        Regression test for https://github.com/astropy/astropy/issues/2750
+
+        Tests that the fake header (for the compressed image) can still be read
+        even if the real header contained a duplicate ZTENSION keyword (the
+        issue applies to any keyword specific to the compression convention,
+        however).
+        """
+
+        arr = np.arange(100, dtype=np.int32)
+        hdu = fits.CompImageHDU(data=arr)
+
+        header = hdu._header
+        # append the duplicate keyword
+        hdu._header.append(('ZTENSION', 'IMAGE'))
+        hdu.writeto(self.temp('test.fits'))
+
+        with fits.open(self.temp('test.fits')) as hdul:
+            assert header == hdul[1]._header
+            # There's no good reason to have a duplicate keyword, but
+            # technically it isn't invalid either :/
+            assert hdul[1]._header.count('ZTENSION') == 2
