@@ -29,7 +29,7 @@ from itertools import chain, islice
 
 import numpy as np
 
-from ..utils import indent, isiterable, isinstancemethod, metadata
+from ..utils import indent, isinstancemethod, metadata
 from ..extern import six
 from ..extern.six.moves import copyreg
 from ..table import Table
@@ -40,7 +40,7 @@ from ..utils.compat import ignored
 from ..utils.exceptions import AstropyDeprecationWarning
 from .utils import (array_repr_oneline, check_broadcast, combine_labels,
                     make_binary_operator_eval, ExpressionTree,
-                    IncompatibleShapeError, AliasDict)
+                    IncompatibleShapeError, AliasDict, get_inputs_and_params)
 
 from .parameters import Parameter, InputParameterError
 
@@ -461,6 +461,12 @@ class Model(object):
     This class sets the constraints and other properties for all individual
     parameters and performs parameter validation.
 
+    The following initialization arguments apply to the majority of Model
+    subclasses by default (exceptions include specialized utility models
+    like `~astropy.modeling.mappings.Mapping`).  Parametric models take all
+    their parameters as arguments, followed by any of the following optional
+    keyword arguments:
+
     Parameters
     ----------
     name : str, optional
@@ -468,6 +474,31 @@ class Model(object):
         (particularly useful for identifying the individual components of a
         compound model).
 
+    meta : dict, optional
+        An optional dict of user-defined metadata to attach to this model.
+        How this is used and interpreted is up to the user or individual use
+        case.
+
+    n_models : int, optional
+        If given an integer greater than 1, a *model set* is instantiated
+        instead of a single model.  This affects how the parameter arguments
+        are interpreted.  In this case each parameter must be given as a list
+        or array--elements of this array are taken along the first axis (or
+        ``model_set_axis`` if specified), such that the Nth element is the
+        value of that parameter for the Nth model in the set.
+
+        See the section on model sets in the documentation for more details.
+
+    model_set_axis : int, optional
+        This argument only applies when creating a model set (i.e. ``n_models >
+        1``).  It changes how parameter values are interpreted.  Normally the
+        first axis of each input parameter array (properly the 0th axis) is
+        taken as the axis corresponding to the model sets.  However, any axis
+        of an input array may be taken as this "model set axis".  This accepts
+        negative integers as well--for example use ``model_set_axis=-1`` if the
+        last (most rapidly changing) axis should be associated with the model
+        sets.
+
     fixed : dict, optional
         Dictionary ``{parameter_name: bool}`` setting the fixed constraint
         for one or more parameters.  `True` means the parameter is held fixed
@@ -1336,9 +1367,9 @@ class Model(object):
             columns = [getattr(self, name).value
                        for name in self.param_names]
 
-        param_table = Table(columns, names=self.param_names)
-
-        parts.append(indent(str(param_table), width=4))
+        if columns:
+            param_table = Table(columns, names=self.param_names)
+            parts.append(indent(str(param_table), width=4))
 
         return '\n'.join(parts)
 
@@ -2251,30 +2282,22 @@ def _custom_model_wrapper(func, fit_deriv=None):
             "callable object")
 
     model_name = func.__name__
-    argspec = inspect.getargspec(func)
-    param_values = argspec.defaults or ()
 
-    nparams = len(param_values)
-    param_names = argspec.args[-nparams:]
+    inputs, params = get_inputs_and_params(func)
 
     if (fit_deriv is not None and
-            len(six.get_function_defaults(fit_deriv)) != nparams):
+            len(six.get_function_defaults(fit_deriv)) != len(params)):
         raise ModelDefinitionError("derivative function should accept "
                                    "same number of parameters as func.")
 
-    if nparams:
-        input_names = argspec.args[:-nparams]
-    else:
-        input_names = argspec.args
-
     # TODO: Maybe have a clever scheme for default output name?
-    if input_names:
-        output_names = (input_names[0],)
+    if inputs:
+        output_names = (inputs[0].name,)
     else:
         output_names = ('x',)
 
-    params = dict((name, Parameter(name, default=default))
-                  for name, default in zip(param_names, param_values))
+    params = dict((param.name, Parameter(param.name, default=param.default))
+                  for param in params)
 
     mod = find_current_module(2)
     if mod:
@@ -2285,7 +2308,7 @@ def _custom_model_wrapper(func, fit_deriv=None):
     members = {
         '__module__': str(modname),
         '__doc__': func.__doc__,
-        'inputs': tuple(input_names),
+        'inputs': tuple(x.name for x in inputs),
         'outputs': output_names,
         'evaluate': staticmethod(func),
     }
