@@ -1,7 +1,8 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """
-Here are all the test parameters and values for the ParametricModels
-defined. There is a dictionary for 1D and a dictionary for 2D models.
+Here are all the test parameters and values for the each
+`~astropy.modeling.FittableModel` defined. There is a dictionary for 1D and a
+dictionary for 2D models.
 
 Explanation of keywords of the dictionaries:
 
@@ -48,13 +49,14 @@ Explanation of keywords of the dictionaries:
     values for the fit (optional)
 """
 
-from __future__ import division
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
 
 from ..functional_models import (
     Gaussian1D, Sine1D, Box1D, Linear1D, Lorentz1D,
-    MexicanHat1D, Trapezoid1D, Const1D, Beta1D,
+    MexicanHat1D, Trapezoid1D, Const1D, Moffat1D,
     Gaussian2D, Const2D, Box2D, MexicanHat2D,
-    TrapezoidDisk2D, AiryDisk2D, Beta2D, Disk2D,
+    TrapezoidDisk2D, AiryDisk2D, Moffat2D, Disk2D,
     Ring2D)
 from ..polynomial import Polynomial1D, Polynomial2D
 from ..powerlaws import (
@@ -128,7 +130,7 @@ models_1D = {
         'integral': 20
     },
 
-    Beta1D: {
+    Moffat1D: {
         'parameters': [1, 0, 1, 2],
         'x_values': [0, 1, -1, 3, -3],
         'y_values': [1.0, 0.25, 0.25, 0.01, 0.01],
@@ -251,7 +253,7 @@ models_2D = {
         'requires_scipy': True
     },
 
-    Beta2D: {
+    Moffat2D: {
         'parameters': [1, 0, 0, 1, 2],
         'x_values': [0, 1, -1, 3, -3],
         'y_values': [0, -1, 3, 1, -3],
