@@ -10,14 +10,15 @@ import numpy as np
 from numpy.testing.utils import (assert_allclose, assert_array_equal,
                                  assert_almost_equal)
 
+from ...extern.six.moves import cPickle as pickle
 from ...tests.helper import pytest
 
 from ..core import Model, ModelDefinitionError
 from ..parameters import Parameter
 from ..models import (Const1D, Shift, Scale, Rotation2D, Gaussian1D,
                       Gaussian2D, Polynomial1D, Polynomial2D,
-                      AffineTransformation2D,
-                      Identity, Mapping)
+                      Chebyshev2D, Legendre2D, Chebyshev1D, Legendre1D,
+                      AffineTransformation2D, Identity, Mapping)
 
 
 @pytest.mark.parametrize(('expr', 'result'),
@@ -789,3 +790,106 @@ def test_inherit_constraints(model):
     assert model.mean_1.fixed is True
     assert model[1].mean.fixed is True
     assert model[1].fixed['mean'] is True
+
+
+def test_compound_custom_inverse():
+    """
+    Test that a compound model with a custom inverse has that inverse applied
+    when the inverse of another model, of which it is a component, is computed.
+    Regression test for https://github.com/astropy/astropy/issues/3542
+    """
+
+    poly = Polynomial1D(1, c0=1, c1=2)
+    scale = Scale(1)
+    shift = Shift(1)
+
+    model1 = poly | scale
+    model1.inverse = poly
+
+    # model1 now has a custom inverse (the polynomial itself, ignoring the
+    # trivial scale factor)
+    model2 = shift | model1
+
+    assert_allclose(model2.inverse(1), (poly | shift.inverse)(1))
+
+    # Make sure an inverse is not allowed if the models were combined with the
+    # wrong operator, or if one of the models doesn't have an inverse defined
+    with pytest.raises(NotImplementedError):
+        (shift + model1).inverse
+
+    with pytest.raises(NotImplementedError):
+        (model1 & poly).inverse
+
+
+@pytest.mark.parametrize('poly', [Chebyshev2D(1, 2), Polynomial2D(2), Legendre2D(1, 2),
+                                  Chebyshev1D(5), Legendre1D(5), Polynomial1D(5)])
+def test_compound_with_polynomials(poly):
+    """
+    Tests that polynomials are scaled when used in compound models.
+    Issue #3699
+    """
+    poly.parameters = [1, 2, 3, 4, 1, 2]
+    shift = Shift(3)
+    model = poly | shift
+    x, y = np.mgrid[:20, :37]
+    result_compound = model(x, y)
+    result = shift(poly(x, y))
+    assert_allclose(result, result_compound)
+
+
+# has to be defined at module level since pickling doesn't work right (in
+# general) for classes defined in functions
+class _TestPickleModel(Gaussian1D + Gaussian1D):
+    pass
+
+
+@pytest.mark.skipif(str("sys.version_info < (2, 7, 3)"))
+def test_pickle_compound():
+    """
+    Regression test for
+    https://github.com/astropy/astropy/issues/3867#issuecomment-114547228
+    """
+
+    # Test pickling a compound model class
+    GG = Gaussian1D + Gaussian1D
+    GG2 = pickle.loads(pickle.dumps(GG))
+    assert GG.param_names == GG2.param_names
+    assert GG.__name__ == GG2.__name__
+    # Test that it works, or at least evaluates successfully
+    assert GG()(0.12345) == GG2()(0.12345)
+
+    # Test pickling a compound model instance
+    g1 = Gaussian1D(1.0, 0.0, 0.1)
+    g2 = Gaussian1D([2.0, 3.0], [0.0, 0.0], [0.2, 0.3])
+    m = g1 + g2
+    m2 = pickle.loads(pickle.dumps(m))
+    assert m.param_names == m2.param_names
+    assert m.__class__.__name__ == m2.__class__.__name__
+    assert np.all(m.parameters == m2.parameters)
+    assert np.all(m(0) == m2(0))
+
+    # Test picling a concrete class
+    p = pickle.dumps(_TestPickleModel, protocol=0)
+    # Note: This is very dependent on the specific protocol, but the point of
+    # this test is that the "concrete" model is pickled in a very simple way
+    # that only specifies the module and class name, and is unpickled by
+    # re-importing the class from the module in which it was defined.  This
+    # should still work for concrete subclasses of compound model classes that
+    # were dynamically generated through an expression
+    exp = b'castropy.modeling.tests.test_compound\n_TestPickleModel\np0\n.'
+    # When testing against the expected value we drop the memo length field
+    # at the end, which may differ between runs
+    assert p[:p.rfind(b'p')] == exp[:exp.rfind(b'p')]
+    assert pickle.loads(p) is _TestPickleModel
+
+
+@pytest.mark.skipif(str("sys.version_info >= (2, 7, 3)"))
+def test_pickle_compound_fallback():
+    """
+    Test fallback for pickling compound model on old versions of Python
+    affected by http://bugs.python.org/issue7689
+    """
+
+    gg = (Gaussian1D + Gaussian1D)()
+    with pytest.raises(RuntimeError):
+        pickle.dumps(gg)
