@@ -247,6 +247,11 @@ class Table(object):
 
         default_names = None
 
+        if (isinstance(data, np.ndarray) and
+                data.shape == (0,) and
+                not data.dtype.names):
+            data = None
+
         if isinstance(data, self.Row):
             data = data._table[data._index:data._index + 1]
 
@@ -264,6 +269,10 @@ class Table(object):
                 default_names = data.dtype.names
             else:
                 init_func = self._init_from_ndarray  # _homog
+                if data.shape == ():
+                    raise ValueError('Can not initialize a Table with a scalar')
+                elif len(data.shape) == 1:
+                    data = data[np.newaxis, :]
                 n_cols = data.shape[1]
 
         elif isinstance(data, dict):
@@ -698,17 +707,18 @@ class Table(object):
             Maximum number of rows to export to the table (set low by default
             to avoid memory issues, since the browser view requires duplicating
             the table in memory).  A negative value of ``max_lines`` indicates
-            no row limit
+            no row limit.
         jsviewer : bool
             If `True`, prepends some javascript headers so that the table is
-            rendered as a https://datatables.net data table.  This allows
-            in-browser searching & sorting.  See `JSViewer
-            <http://www.jsviewer.com/>`_
+            rendered as a `DataTables <https://datatables.net>`_ data table.
+            This allows in-browser searching & sorting.
         jskwargs : dict
-            Passed to the `JSViewer`_ init.
+            Passed to the `astropy.table.JSViewer` init. Default to
+            ``{'use_local_files': True}`` which means that the JavaScipt
+            librairies will be served from local copies.
         tableid : str or `None`
-            An html ID tag for the table.  Default is "table{id}", where id is
-            the unique integer id of the table object, id(self).
+            An html ID tag for the table.  Default is ``table{id}``, where id
+            is the unique integer id of the table object, id(self).
         browser : str
             Any legal browser name, e.g. ``'firefox'``, ``'chrome'``,
             ``'safari'`` (for mac, you may need to use ``'open -a
@@ -719,6 +729,8 @@ class Table(object):
         import os
         import webbrowser
         import tempfile
+        from ..extern.six.moves.urllib.parse import urljoin
+        from ..extern.six.moves.urllib.request import pathname2url
 
         # We can't use NamedTemporaryFile here because it gets deleted as
         # soon as it gets garbage collected.
@@ -727,17 +739,18 @@ class Table(object):
         path = os.path.join(tmpdir, 'table.html')
 
         with open(path, 'w') as tmp:
-
             if jsviewer:
                 self.write(tmp, format='jsviewer', css=css, max_lines=max_lines,
                            jskwargs=jskwargs, table_id=tableid)
             else:
                 self.write(tmp, format='html')
 
-            if browser == 'default':
-                webbrowser.open("file://" + path)
-            else:
-                webbrowser.get(browser).open("file://" + path)
+        try:
+            br = webbrowser.get(None if browser == 'default' else browser)
+        except webbrowser.Error:
+            log.error("Browser '%s' not found." % browser)
+        else:
+            br.open(urljoin('file:', pathname2url(path)))
 
     def pformat(self, max_lines=None, max_width=None, show_name=True,
                 show_unit=None, show_dtype=False, html=False, tableid=None):
@@ -2062,3 +2075,8 @@ class QTable(Table):
         If ``col`` is a string then it refers to a column name in this table.
         """
         return super(QTable, self)._is_mixin_column(col, quantity_is_mixin=True)
+
+    def __getstate__(self):
+        columns = dict((key, col if isinstance(col, BaseColumn) else col_copy(col))
+                for key, col in self.columns.items())
+        return (columns, self.meta)
