@@ -107,13 +107,6 @@ class TestRunner(object):
         """
         The docstring for this method lives in astropy/__init__.py:test
         """
-        try:
-            get_ipython()
-        except NameError:
-            pass
-        else:
-            raise RuntimeError(
-                "Running astropy tests inside of IPython is not supported.")
 
         if coverage:
             warnings.warn(
@@ -349,9 +342,10 @@ class raises(object):
         def test_foo():
             x = 1/0
 
-    This can also be used a context manager, in which case it is just an alias
-    for the `pytest.raises` context manager (because the two have the same name
-    this help avoid confusion by being flexible).
+    This can also be used a context manager, in which case it is just
+    an alias for the ``pytest.raises`` context manager (because the
+    two have the same name this help avoid confusion by being
+    flexible).
     """
 
     # pep-8 naming exception -- this is a decorator class
@@ -380,7 +374,6 @@ def enable_deprecations_as_exceptions(include_astropy_deprecations=True):
     """
     Turn on the feature that turns deprecations into exceptions.
     """
-
     global _deprecations_as_exceptions
     _deprecations_as_exceptions = True
 
@@ -398,9 +391,6 @@ def treat_deprecations_as_exceptions():
     This completely resets the warning filters and any "already seen"
     warning state.
     """
-    if not _deprecations_as_exceptions:
-        return
-
     # First, totally reset the warning state
     for module in list(six.itervalues(sys.modules)):
         # We don't want to deal with six.MovedModules, only "real"
@@ -409,6 +399,9 @@ def treat_deprecations_as_exceptions():
             hasattr(module, '__warningregistry__')):
             del module.__warningregistry__
 
+    if not _deprecations_as_exceptions:
+        return
+
     warnings.resetwarnings()
 
     # Hide the next couple of DeprecationWarnings
@@ -443,7 +436,7 @@ def treat_deprecations_as_exceptions():
         # py.test's warning.showwarning does not include the line argument
         # on Python 2.6, so we need to explicitly ignore this warning.
         warnings.filterwarnings(
-            "always",
+            "ignore",
             r"functions overriding warnings\.showwarning\(\) must support "
             r"the 'line' argument",
             DeprecationWarning)
@@ -452,20 +445,30 @@ def treat_deprecations_as_exceptions():
         # py.test reads files with the 'U' flag, which is now
         # deprecated in Python 3.4.
         warnings.filterwarnings(
-            "always",
+            "ignore",
             r"'U' mode is deprecated",
             DeprecationWarning)
 
         # BeautifulSoup4 triggers a DeprecationWarning in stdlib's
         # html module.x
         warnings.filterwarnings(
-            "always",
-            "The strict argument and mode are deprecated.",
+            "ignore",
+            r"The strict argument and mode are deprecated\.",
             DeprecationWarning)
         warnings.filterwarnings(
-            "always",
-            "The value of convert_charrefs will become True in 3.5. "
-            "You are encouraged to set the value explicitly.",
+            "ignore",
+            r"The value of convert_charrefs will become True in 3\.5\. "
+            r"You are encouraged to set the value explicitly\.",
+            DeprecationWarning)
+
+    if sys.version_info[:2] >= (3, 5):
+        # py.test raises this warning on Python 3.5.
+        # This can be removed when fixed in py.test.
+        # See https://github.com/pytest-dev/pytest/pull/1009
+        warnings.filterwarnings(
+            "ignore",
+            r"inspect\.getargspec\(\) is deprecated, use "
+            r"inspect\.signature\(\) instead",
             DeprecationWarning)
 
 
@@ -615,15 +618,33 @@ def check_pickling_recovery(original, protocol):
                                     class_history)
 
 
-def assert_quantity_allclose(actual, desired, rtol=1.e-7, atol=None, err_msg='', verbose=True):
+def assert_quantity_allclose(actual, desired, rtol=1.e-7, atol=None,
+                             **kwargs):
     """
     Raise an assertion if two objects are not equal up to desired tolerance.
 
     This is a :class:`~astropy.units.Quantity`-aware version of
     :func:`numpy.testing.assert_allclose`.
     """
-
     import numpy as np
+    np.testing.assert_allclose(*_unquantify_allclose_arguments(actual, desired,
+                                                               rtol, atol),
+                               **kwargs)
+
+
+def quantity_allclose(a, b, rtol=1.e-5, atol=None, **kwargs):
+    """
+    Returns True if two arrays are element-wise equal within a tolerance.
+
+    This is a :class:`~astropy.units.Quantity`-aware version of
+    :func:`numpy.allclose`.
+    """
+    import numpy as np
+    return np.allclose(*_unquantify_allclose_arguments(a, b, rtol, atol),
+                       **kwargs)
+
+
+def _unquantify_allclose_arguments(actual, desired, rtol, atol):
     from .. import units as u
 
     actual = u.Quantity(actual, subok=True, copy=False)
@@ -632,7 +653,9 @@ def assert_quantity_allclose(actual, desired, rtol=1.e-7, atol=None, err_msg='',
     try:
         desired = desired.to(actual.unit)
     except u.UnitsError:
-        raise u.UnitsError("Units for 'desired' ({0}) and 'actual' ({1}) are not convertible".format(desired.unit, actual.unit))
+        raise u.UnitsError("Units for 'desired' ({0}) and 'actual' ({1}) "
+                           "are not convertible"
+                           .format(desired.unit, actual.unit))
 
     if atol is None:
         # by default, we assume an absolute tolerance of 0
@@ -642,7 +665,9 @@ def assert_quantity_allclose(actual, desired, rtol=1.e-7, atol=None, err_msg='',
         try:
             atol = atol.to(actual.unit)
         except u.UnitsError:
-            raise u.UnitsError("Units for 'atol' ({0}) and 'actual' ({1}) are not convertible".format(atol.unit, actual.unit))
+            raise u.UnitsError("Units for 'atol' ({0}) and 'actual' ({1}) "
+                               "are not convertible"
+                               .format(atol.unit, actual.unit))
 
     rtol =  u.Quantity(rtol, subok=True, copy=False)
     try:
@@ -650,6 +675,4 @@ def assert_quantity_allclose(actual, desired, rtol=1.e-7, atol=None, err_msg='',
     except:
         raise u.UnitsError("`rtol` should be dimensionless")
 
-    np.testing.assert_allclose(actual.value, desired.value,
-                               rtol=rtol.value, atol=atol.value,
-                               err_msg=err_msg, verbose=verbose)
+    return actual.value, desired.value, rtol.value, atol.value
