@@ -9,6 +9,7 @@ astronomy.
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
+import itertools
 import fnmatch
 import time
 
@@ -18,6 +19,7 @@ import numpy as np
 
 from .. import units as u
 from .. import _erfa as erfa
+from ..units import UnitConversionError
 from ..utils.compat.misc import override__dir__
 from ..extern import six
 
@@ -113,6 +115,13 @@ class Time(object):
     formats (e.g. JD) where very high precision (better than 64-bit precision)
     is required.
 
+    The allowed values for ``format`` can be listed with::
+
+      >>> sorted(Time.FORMATS)
+      ['astropy_time', 'byear', 'byear_str', 'cxcsec', 'datetime',
+      'decimalyear', 'gps', 'iso', 'isot', 'jd', 'jyear', 'jyear_str', 'mjd',
+      'plot_date', 'unix', 'yday']
+
     Parameters
     ----------
     val : sequence, str, number, or `~astropy.time.Time` object
@@ -122,7 +131,8 @@ class Time(object):
     format : str, optional
         Format of input value(s)
     scale : str, optional
-        Time scale of input value(s)
+        Time scale of input value(s), must be one of the following:
+        ('tai', 'tcb', 'tcg', 'tdb', 'tt', 'ut1', 'utc')
     precision : int, optional
         Digits of precision in string representation of time
     in_subfmt : str, optional
@@ -272,6 +282,8 @@ class Time(object):
             try:
                 return FormatClass(val, val2, scale, self.precision,
                                    self.in_subfmt, self.out_subfmt)
+            except UnitConversionError:
+                raise
             except (ValueError, TypeError):
                 pass
         else:
@@ -510,9 +522,11 @@ class Time(object):
 
         gst = self._erfa_sidereal_time(available_models[model.upper()])
         return Longitude(gst + longitude, u.hourangle)
-    sidereal_time.__doc__ = sidereal_time.__doc__.format(
-        'apparent', sorted(SIDEREAL_TIME_MODELS['apparent'].keys()),
-        'mean', sorted(SIDEREAL_TIME_MODELS['mean'].keys()))
+
+    if isinstance(sidereal_time.__doc__, six.string_types):
+        sidereal_time.__doc__ = sidereal_time.__doc__.format(
+            'apparent', sorted(SIDEREAL_TIME_MODELS['apparent'].keys()),
+            'mean', sorted(SIDEREAL_TIME_MODELS['mean'].keys()))
 
     def _erfa_sidereal_time(self, model):
         """Calculate a sidereal time using a IAU precession/nutation model."""
@@ -648,6 +662,21 @@ class Time(object):
         """
         return self.copy()
 
+    def __iter__(self):
+        if self.isscalar:
+            raise TypeError('scalar {0!r} object is not iterable.'.format(
+                self.__class__.__name__))
+
+        def time_iter():
+            try:
+                for idx in itertools.count():
+                    yield self[idx]
+            except IndexError:
+                # Results in StopIteration
+                pass
+
+        return time_iter()
+
     def __getitem__(self, item):
         if self.isscalar:
             raise TypeError('scalar {0!r} object is not subscriptable.'.format(
@@ -1038,6 +1067,20 @@ class TimeDelta(Time):
     numeric input formats (e.g. JD) where very high precision (better than
     64-bit precision) is required.
 
+    The allowed values for ``format`` can be listed with::
+
+      >>> sorted(TimeDelta.FORMATS)
+      ['jd', 'sec']
+
+    Note that for time differences, the scale can be among three groups:
+    geocentric ('tai', 'tt', 'tcg'), barycentric ('tcb', 'tdb'), and rotational
+    ('ut1'). Within each of these, the scales for time differences are the
+    same. Conversion between geocentric and barycentric is possible, as there
+    is only a scale factor change, but one cannot convert to or from 'ut1', as
+    this requires knowledge of the actual times, not just their difference. For
+    a similar reason, 'utc' is not a valid scale for a time difference: a UTC
+    day is not always 86400 seconds.
+
     Parameters
     ----------
     val : numpy ndarray, list, str, number, or `~astropy.time.TimeDelta` object
@@ -1047,7 +1090,10 @@ class TimeDelta(Time):
     format : str, optional
         Format of input value(s)
     scale : str, optional
-        Time scale of input value(s)
+        Time scale of input value(s), must be one of the following values:
+        ('tdb', 'tt', 'ut1', 'tcg', 'tcb', 'tai'). If not given (or
+        ``None``), the scale is arbitrary; when added or subtracted from a
+        ``Time`` instance, it will be used without conversion.
     copy : bool, optional
         Make a copy of the input values
     """
@@ -1329,15 +1375,14 @@ class TimeFormat(object):
             raise TypeError('Input values for {0} class must be finite doubles'
                             .format(self.name))
 
-        if hasattr(val1, 'to'):
+        if getattr(val1, 'unit', None) is not None:
             # set possibly scaled unit any quantities should be converted to
             _unit = u.CompositeUnit(getattr(self, 'unit', 1.), [u.day], [1])
             val1 = val1.to(_unit).value
             if val2 is not None:
                 val2 = val2.to(_unit).value
-        else:
-            if hasattr(val2, 'to'):
-                raise TypeError('Cannot mix float and Quantity inputs')
+        elif getattr(val2, 'unit', None) is not None:
+            raise TypeError('Cannot mix float and Quantity inputs')
 
         if val2 is None:
             val2 = np.zeros_like(val1)
