@@ -8,11 +8,17 @@ Handles a "generic" string format for units
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
+import keyword
 import os
 import re
 
+from ...extern import six
+from ...extern.six.moves import zip
+
 from .base import Base
 from . import utils
+from ..utils import is_effectively_unity
+from ...utils.misc import did_you_mean
 
 
 # TODO: Support logarithmic units using bracketed syntax
@@ -22,7 +28,9 @@ class CDS(Base):
     Support the `Centre de Données astronomiques de Strasbourg
     <http://cds.u-strasbg.fr/>`_ `Standards for Astronomical
     Catalogues 2.0 <http://cds.u-strasbg.fr/doc/catstd-3.2.htx>`_
-    format.  This format is used by VOTable up to version 1.2.
+    format, and the `complete set of supported units
+    <http://vizier.u-strasbg.fr/cgi-bin/Unit>`_.  This format is used
+    by VOTable up to version 1.2.
     """
     def __init__(self):
         # Build this on the class, so it only gets generated once.
@@ -34,54 +42,14 @@ class CDS(Base):
 
     @staticmethod
     def _generate_unit_names():
-        import keyword
+        from .. import cds
         from ... import units as u
-        from .. import core
-
-        bases = [
-            'A', 'a', 'arcmin', 'arcsec', 'AU', 'barn', 'bit', 'byte',
-            'C', 'cd', 'eV', 'F', 'g', 'H', 'Hz', 'J', 'Jy', 'K',
-            'lm', 'lx', 'm', 'mag', 'mol', 'N', 'Ohm', 'Pa', 'pc',
-            'rad', 's', 'S', 'solLum', 'solMass', 'sr', 'T', 'V', 'W',
-            'Wb', 'yr']
-
-        # These are bases which don't have prefix units in astropy.units
-        # itself, but that we need to fake for the sake of CDS.
-        faux_bases = [
-            'ct', 'D', 'd', 'deg', 'h', 'min', 'pix', 'Ry', 'solRad',
-            'Sun']
-
-        # "mas" doesn't have prefixes, according to the cds standard
-        unprefixed = [
-            'mas']
-
-        # We need to define all of the base units first, and then
-        # only add prefixed units if they don't already exist in names
-        # to prevent ambiguities like cd (candela vs. centi-day)
 
         names = {}
 
-        names['%'] = u.Unit(0.01)
-
-        for base in bases + faux_bases + unprefixed:
-            names[base] = getattr(u, base)
-
-        for base in bases:
-            for p_name, p_long_name, p_value in core.si_prefixes:
-                for name in p_name:
-                    key = name + base
-                    if key not in names:
-                        if keyword.iskeyword(key):
-                            continue
-                        names[key] = getattr(u, key)
-
-        for base in faux_bases:
-            names[base] = getattr(u, base)
-            for p_name, p_long_name, p_value in core.si_prefixes:
-                for name in p_name:
-                    key = name + base
-                    if key not in names:
-                        names[key] = u.Unit(p_value * getattr(u, base))
+        for key, val in cds.__dict__.items():
+            if isinstance(val, u.UnitBase):
+                names[key] = val
 
         return names
 
@@ -135,12 +103,12 @@ class CDS(Base):
             t.value = float(t.value + '1')
             return t
 
-        def t_X(t):
-            r'x'
+        def t_X(t):  # multiplication for factor in front of unit
+            r'[x×]'
             return t
 
         def t_UNIT(t):
-            r'\%|([a-zA-Z][a-zA-Z_]*)'
+            r'\%|°|\\h|((?!\d)\w)+'
             t.value = cls._get_unit(t)
             return t
 
@@ -153,21 +121,24 @@ class CDS(Base):
 
         try:
             from . import cds_lextab
-            lexer = lex.lex(optimize=True, lextab=cds_lextab)
+            lexer = lex.lex(optimize=True, lextab=cds_lextab,
+                            reflags=re.UNICODE)
         except ImportError:
             lexer = lex.lex(optimize=True, lextab='cds_lextab',
-                            outputdir=os.path.dirname(__file__))
+                            outputdir=os.path.dirname(__file__),
+                            reflags=re.UNICODE)
 
         def p_main(p):
             '''
             main : factor combined_units
                  | combined_units
+                 | factor
             '''
+            from ..core import Unit
             if len(p) == 3:
-                from ..core import Unit
                 p[0] = Unit(p[1] * p[2])
             else:
-                p[0] = p[1]
+                p[0] = Unit(p[1])
 
         def p_combined_units(p):
             '''
@@ -283,17 +254,22 @@ class CDS(Base):
     def _get_unit(cls, t):
         try:
             return cls._parse_unit(t.value)
-        except ValueError:
+        except ValueError as e:
             raise ValueError(
-                "At col {0}, {1!r} is not a valid unit".format(
-                    t.lexpos, t.value))
+                "At col {0}, {1}".format(
+                    t.lexpos, six.text_type(e)))
 
     @classmethod
-    def _parse_unit(cls, unit):
+    def _parse_unit(cls, unit, detailed_exception=True):
         if unit not in cls._units:
-            raise ValueError(
-                "Unit {0!r} not supported by the CDS SAC "
-                "standard.".format(unit))
+            if detailed_exception:
+                raise ValueError(
+                    "Unit '{0}' not supported by the CDS SAC "
+                    "standard. {1}".format(
+                        unit, did_you_mean(
+                            unit, cls._units)))
+            else:
+                raise ValueError()
 
         return cls._units[unit]
 
@@ -301,20 +277,21 @@ class CDS(Base):
         if ' ' in s:
             raise ValueError('CDS unit must not contain whitespace')
 
+        if not isinstance(s, six.text_type):
+            s = s.decode('ascii')
+
         # This is a short circuit for the case where the string
         # is just a single unit name
         try:
-            return self._parse_unit(s)
+            return self._parse_unit(s, detailed_exception=False)
         except ValueError:
             try:
                 return self._parser.parse(s, lexer=self._lexer, debug=debug)
             except ValueError as e:
-                if str(e):
-                    raise ValueError("{0} in unit {1!r}".format(
-                        str(e), s))
+                if six.text_type(e):
+                    raise ValueError(six.text_type(e))
                 else:
-                    raise ValueError(
-                        "Syntax error parsing unit {0!r}".format(s))
+                    raise ValueError("Syntax error")
 
     def _get_unit_name(self, unit):
         return unit.get_format_name('cds')
@@ -336,12 +313,16 @@ class CDS(Base):
         unit = utils.decompose_to_known_units(unit, self._get_unit_name)
 
         if isinstance(unit, core.CompositeUnit):
+            if(unit.physical_type == 'dimensionless' and
+               is_effectively_unity(unit.scale*100.)):
+                return '%'
+
             if unit.scale == 1:
                 s = ''
             else:
                 m, e = utils.split_mantissa_exponent(unit.scale)
                 parts = []
-                if m:
+                if m not in ('', '1'):
                     parts.append(m)
                 if e:
                     if not e.startswith('-'):
@@ -349,10 +330,12 @@ class CDS(Base):
                     parts.append('10{0}'.format(e))
                 s = 'x'.join(parts)
 
-            pairs = zip(unit.bases, unit.powers)
-            pairs.sort(key=lambda x: x[1], reverse=True)
+            pairs = list(zip(unit.bases, unit.powers))
+            if len(pairs) > 0:
+                pairs.sort(key=lambda x: x[1], reverse=True)
+
+                s += self._format_unit_list(pairs)
 
-            s += self._format_unit_list(pairs)
         elif isinstance(unit, core.NamedUnit):
             s = self._get_unit_name(unit)
 
