@@ -71,17 +71,17 @@ def test_logarithmic(log_unit):
                       1.e-10*log_unit)
 
 
-functions = [u.doppler_optical, u.doppler_radio, u.doppler_relativistic]
+doppler_functions = [u.doppler_optical, u.doppler_radio, u.doppler_relativistic]
 
 
-@pytest.mark.parametrize(('function'), functions)
+@pytest.mark.parametrize(('function'), doppler_functions)
 def test_doppler_frequency_0(function):
     rest = 105.01 * u.GHz
     velo0 = rest.to(u.km/u.s, equivalencies=function(rest))
     assert velo0.value == 0
 
 
-@pytest.mark.parametrize(('function'), functions)
+@pytest.mark.parametrize(('function'), doppler_functions)
 def test_doppler_wavelength_0(function):
     rest = 105.01 * u.GHz
     q1 = 0.00285489437196 * u.m
@@ -89,7 +89,7 @@ def test_doppler_wavelength_0(function):
     np.testing.assert_almost_equal(velo0.value, 0, decimal=6)
 
 
-@pytest.mark.parametrize(('function'), functions)
+@pytest.mark.parametrize(('function'), doppler_functions)
 def test_doppler_energy_0(function):
     rest = 105.01 * u.GHz
     q1 = 0.000434286445543 * u.eV
@@ -97,7 +97,7 @@ def test_doppler_energy_0(function):
     np.testing.assert_almost_equal(velo0.value, 0, decimal=6)
 
 
-@pytest.mark.parametrize(('function'), functions)
+@pytest.mark.parametrize(('function'), doppler_functions)
 def test_doppler_frequency_circle(function):
     rest = 105.01 * u.GHz
     shifted = 105.03 * u.GHz
@@ -106,7 +106,7 @@ def test_doppler_frequency_circle(function):
     np.testing.assert_almost_equal(freq.value, shifted.value, decimal=7)
 
 
-@pytest.mark.parametrize(('function'), functions)
+@pytest.mark.parametrize(('function'), doppler_functions)
 def test_doppler_wavelength_circle(function):
     rest = 105.01 * u.nm
     shifted = 105.03 * u.nm
@@ -115,7 +115,7 @@ def test_doppler_wavelength_circle(function):
     np.testing.assert_almost_equal(wav.value, shifted.value, decimal=7)
 
 
-@pytest.mark.parametrize(('function'), functions)
+@pytest.mark.parametrize(('function'), doppler_functions)
 def test_doppler_energy_circle(function):
     rest = 1.0501 * u.eV
     shifted = 1.0503 * u.eV
@@ -126,7 +126,7 @@ def test_doppler_energy_circle(function):
 
 values_ghz = (999.899940784289,999.8999307714406,999.8999357778647)
 @pytest.mark.parametrize(('function', 'value'),
-                         list(zip(functions, values_ghz)))
+                         list(zip(doppler_functions, values_ghz)))
 def test_30kms(function, value):
     rest = 1000 * u.GHz
     velo = 30 * u.km/u.s
@@ -134,6 +134,13 @@ def test_30kms(function, value):
     np.testing.assert_almost_equal(shifted.value, value, decimal=7)
 
 
+bad_values = (5, 5*u.Jy, None)
+@pytest.mark.parametrize(('function', 'value'),
+                         list(zip(doppler_functions, bad_values)))
+def test_bad_restfreqs(function, value):
+    with pytest.raises(u.UnitsError):
+        function(value)
+
 def test_massenergy():
     # The relative tolerance of these tests is set by the uncertainties
     # in the charge of the electron, which is known to about
@@ -476,6 +483,14 @@ def test_equivalency_context():
     assert all(eq in set(eq_on) for eq in eq_off)
     assert set(eq_off) < set(eq_on)
 
+    # Check the equivalency manager also works in ufunc evaluations,
+    # not just using (wrong) scaling. [#2496]
+    l2v = u.doppler_optical(6000 * u.angstrom)
+    l1 = 6010 * u.angstrom
+    assert l1.to(u.km/u.s, equivalencies=l2v) > 100. * u.km / u.s
+    with u.set_enabled_equivalencies(l2v):
+        assert l1 > 100. * u.km / u.s
+        assert abs((l1 - 500. * u.km / u.s).to(u.angstrom)) < 1. * u.km/u.s
 
 def test_equivalency_context_manager():
     base_registry = u.get_current_unit_registry()
@@ -519,11 +534,10 @@ def test_temperature():
 
 
 def test_temperature_energy():
-    from ... import constants
     x = 1000 * u.K
     y = (x * constants.k_B).to(u.keV)
-    assert_allclose(x.to(u.keV, u.temperature_energy()).value, y)
-    assert_allclose(y.to(u.K, u.temperature_energy()).value, x)
+    assert_allclose(x.to(u.keV, u.temperature_energy()).value, y.value)
+    assert_allclose(y.to(u.K, u.temperature_energy()).value, x.value)
 
 
 def test_compose_equivalencies():
