@@ -94,6 +94,18 @@ class TestConeSearch(object):
 
         assert tab.array.size > 0
 
+    def test_timeout(self):
+        """Test time out error."""
+        try:
+            with data.conf.set_temp('remote_timeout', 0.001):
+                tab = conesearch.conesearch(
+                    SCS_CENTER, SCS_RADIUS, pedantic=self.pedantic,
+                    verbose=self.verbose, catalog_db=self.url)
+        except VOSError as e:
+            assert 'timed out' in str(e), 'test_timeout failed'
+        else:
+            raise Exception('test_timeout failed')
+
     def test_searches(self):
         tab_2 = conesearch.conesearch(
             SCS_CENTER, SCS_RADIUS, catalog_db=self.url,
@@ -153,8 +165,8 @@ class TestConeSearch(object):
             assert tab.array.size > 0
 
     @pytest.mark.parametrize(('center', 'radius'),
-                             [((SCS_RA, SCS_DEC), 1.0),
-                              (SCS_CENTER, 1.0 * u.degree)])
+                             [((SCS_RA, SCS_DEC), 0.8),
+                              (SCS_CENTER, 0.8 * u.degree)])
     def test_prediction(self,  center, radius):
         """Prediction tests are not very accurate but will have to do."""
         t_1, tab_1 = conesearch.conesearch_timer(
